ControlPoint

Struct ControlPoint 

pub struct ControlPoint {
    pub friendly_name: String,
    pub uuid: Option<String>,
    pub port: Option<u16>,
}
This represents a specific control point, this is optional for v1.0 and v1.1 messages but the friendly_name field is required by the 2.0 specification.

Fields

friendly_name: String

Specifies the friendly name of the control point. The friendly name is vendor specific.

uuid: Option<String>

UUID of the control point. When the control point is implemented in a UPnP device it is recommended to use the UDN of the co-located UPnP device.

port: Option<u16>

A control point can request that a device replies to a TCP port on the control point. When this header is present it identifies the TCP port on which the device can reply to the search.